import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useState, useEffect, useRef } from "react";
import { Box } from "@primer/react";
import { PageConfig } from '@jupyterlab/coreutils';
import { useJupyter } from "../../jupyter/JupyterContext";
import JupyterLabAppAdapter from "./JupyterLabAppAdapter";
import { JupyterLabAppCorePlugins } from "./JupyterLabAppPlugins";
import JupyterLabAppCss from "./JupyterLabAppCss";
// The webpack public path needs to be set before loading the CSS assets.
global.__webpack_public_path__ = PageConfig.getOption('fullStaticUrl') + '/';
export const JupyterLabApp = (props) => {
    const { hostId, position, height, width, headless, theme, onReady } = props;
    const { serviceManager } = useJupyter();
    const ref = useRef(null);
    const [_, setAdapter] = useState();
    useEffect(() => {
        if (ref && serviceManager) {
            const adapter = new JupyterLabAppAdapter({
                ...props,
                serviceManager,
            });
            adapter.ready.then(() => {
                onReady(adapter);
            });
            setAdapter(adapter);
        }
    }, [hostId, ref, serviceManager, theme]);
    return (_jsx(_Fragment, { children: _jsxs(Box, { sx: {
                '& .jp-LabShell': {
                    position: position,
                    height: height,
                    width: width,
                    display: headless ? 'none' : 'inherit',
                },
            }, children: [_jsx(JupyterLabAppCss, { theme: theme }), _jsx("div", { ref: ref, id: hostId })] }) }));
};
JupyterLabApp.defaultProps = {
    hostId: "app-example-id",
    extensions: [],
    mimeExtensions: [],
    extensionPromises: JupyterLabAppCorePlugins.extensionPromises,
    mimeExtensionPromises: JupyterLabAppCorePlugins.mimeExtensionPromises,
    position: "relative",
    width: "100%",
    height: "100vh",
    devMode: false,
    theme: 'light',
    headless: false,
    onReady: (jupyterlabAppAdapter) => { }
};
export default JupyterLabApp;
//# sourceMappingURL=JupyterLabApp.js.map