import React from "react";
import { ServiceManager, ServerConnection, KernelManager } from '@jupyterlab/services';
import { InjectableStore } from '../state/redux/Store';
import Kernel from './kernel/Kernel';
import { JupyterLabTheme } from "./lab/JupyterLabTheme";
/**
 * The type for the Jupyter context.
 */
export type JupyterContextType = {
    baseUrl: string;
    defaultKernel?: Kernel;
    disableCssLoading?: boolean;
    injectableStore: InjectableStore;
    kernelManager?: KernelManager;
    lite: boolean;
    serverSettings: ServerConnection.ISettings;
    serviceManager?: ServiceManager;
    setVariant: (value: string) => void;
    startDefaultKernel: boolean;
    variant: string;
    wsUrl: string;
};
/**
 * The instance for the Jupyter context.
 */
export declare const JupyterContext: React.Context<JupyterContextType | undefined>;
export declare const useJupyter: () => JupyterContextType;
/**
 * The type for the Jupyter context consumer.
 */
export declare const JupyterContextConsumer: React.Consumer<JupyterContextType | undefined>;
/**
 * Utiliy method to ensure the Jupyter context is authenticated
 * with the Jupyter server.
 */
export declare const ensureJupyterAuth: (serverSettings: ServerConnection.ISettings) => Promise<boolean>;
/**
 * The type for the properties of the Jupyter context.
 */
type JupyterContextProps = {
    baseUrl: string;
    children: React.ReactNode;
    defaultKernelName: string;
    disableCssLoading?: boolean;
    injectableStore: InjectableStore;
    lite: boolean;
    startDefaultKernel: boolean;
    theme: JupyterLabTheme;
    useRunningKernelId?: string;
    useRunningKernelIndex: number;
    variant: string;
    wsUrl: string;
};
export declare const createServerSettings: (baseUrl: string, wsUrl: string) => ServerConnection.ISettings;
/**
 * The Jupyter context provider.
 */
export declare const JupyterContextProvider: React.FC<JupyterContextProps>;
export {};
